# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from proto import transaction_pb2 as proto_dot_transaction__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in proto/transaction_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TransactionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetCurrentTransactions = channel.unary_unary(
                '/transaction.TransactionService/GetCurrentTransactions',
                request_serializer=proto_dot_transaction__pb2.TransactionRequest.SerializeToString,
                response_deserializer=proto_dot_transaction__pb2.CurrentTransactionResponse.FromString,
                _registered_method=True)
        self.GetPastTransactions = channel.unary_unary(
                '/transaction.TransactionService/GetPastTransactions',
                request_serializer=proto_dot_transaction__pb2.PositionHistoryRequest.SerializeToString,
                response_deserializer=proto_dot_transaction__pb2.PositionHistoryResponse.FromString,
                _registered_method=True)
        self.BidPlaced = channel.unary_unary(
                '/transaction.TransactionService/BidPlaced',
                request_serializer=proto_dot_transaction__pb2.BidPlaceRequest.SerializeToString,
                response_deserializer=proto_dot_transaction__pb2.DBCommitResponse.FromString,
                _registered_method=True)
        self.BidFilled = channel.unary_unary(
                '/transaction.TransactionService/BidFilled',
                request_serializer=proto_dot_transaction__pb2.BidFillRequest.SerializeToString,
                response_deserializer=proto_dot_transaction__pb2.DBCommitResponse.FromString,
                _registered_method=True)
        self.AskPlaced = channel.unary_unary(
                '/transaction.TransactionService/AskPlaced',
                request_serializer=proto_dot_transaction__pb2.AskPlaceRequest.SerializeToString,
                response_deserializer=proto_dot_transaction__pb2.DBCommitResponse.FromString,
                _registered_method=True)
        self.AskFilled = channel.unary_unary(
                '/transaction.TransactionService/AskFilled',
                request_serializer=proto_dot_transaction__pb2.AskFillRequest.SerializeToString,
                response_deserializer=proto_dot_transaction__pb2.DBCommitResponse.FromString,
                _registered_method=True)
        self.OrderFailedAfterBidPlaced = channel.unary_unary(
                '/transaction.TransactionService/OrderFailedAfterBidPlaced',
                request_serializer=proto_dot_transaction__pb2.UuidRequest.SerializeToString,
                response_deserializer=proto_dot_transaction__pb2.DBCommitResponse.FromString,
                _registered_method=True)
        self.OrderFailedAfterAskPlaced = channel.unary_unary(
                '/transaction.TransactionService/OrderFailedAfterAskPlaced',
                request_serializer=proto_dot_transaction__pb2.UuidRequest.SerializeToString,
                response_deserializer=proto_dot_transaction__pb2.DBCommitResponse.FromString,
                _registered_method=True)


class TransactionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetCurrentTransactions(self, request, context):
        """1. 현재 보유 포지션 조회 bot 및 front가 둘다 요청 가능 (단일 요청-응답)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPastTransactions(self, request, context):
        """2. 과거 포지션 내역 조회 (단일 요청-응답)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BidPlaced(self, request, context):
        """3. bot에서 기존에 불렀던 함수들 재추가
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BidFilled(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AskPlaced(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AskFilled(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OrderFailedAfterBidPlaced(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OrderFailedAfterAskPlaced(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TransactionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetCurrentTransactions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurrentTransactions,
                    request_deserializer=proto_dot_transaction__pb2.TransactionRequest.FromString,
                    response_serializer=proto_dot_transaction__pb2.CurrentTransactionResponse.SerializeToString,
            ),
            'GetPastTransactions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPastTransactions,
                    request_deserializer=proto_dot_transaction__pb2.PositionHistoryRequest.FromString,
                    response_serializer=proto_dot_transaction__pb2.PositionHistoryResponse.SerializeToString,
            ),
            'BidPlaced': grpc.unary_unary_rpc_method_handler(
                    servicer.BidPlaced,
                    request_deserializer=proto_dot_transaction__pb2.BidPlaceRequest.FromString,
                    response_serializer=proto_dot_transaction__pb2.DBCommitResponse.SerializeToString,
            ),
            'BidFilled': grpc.unary_unary_rpc_method_handler(
                    servicer.BidFilled,
                    request_deserializer=proto_dot_transaction__pb2.BidFillRequest.FromString,
                    response_serializer=proto_dot_transaction__pb2.DBCommitResponse.SerializeToString,
            ),
            'AskPlaced': grpc.unary_unary_rpc_method_handler(
                    servicer.AskPlaced,
                    request_deserializer=proto_dot_transaction__pb2.AskPlaceRequest.FromString,
                    response_serializer=proto_dot_transaction__pb2.DBCommitResponse.SerializeToString,
            ),
            'AskFilled': grpc.unary_unary_rpc_method_handler(
                    servicer.AskFilled,
                    request_deserializer=proto_dot_transaction__pb2.AskFillRequest.FromString,
                    response_serializer=proto_dot_transaction__pb2.DBCommitResponse.SerializeToString,
            ),
            'OrderFailedAfterBidPlaced': grpc.unary_unary_rpc_method_handler(
                    servicer.OrderFailedAfterBidPlaced,
                    request_deserializer=proto_dot_transaction__pb2.UuidRequest.FromString,
                    response_serializer=proto_dot_transaction__pb2.DBCommitResponse.SerializeToString,
            ),
            'OrderFailedAfterAskPlaced': grpc.unary_unary_rpc_method_handler(
                    servicer.OrderFailedAfterAskPlaced,
                    request_deserializer=proto_dot_transaction__pb2.UuidRequest.FromString,
                    response_serializer=proto_dot_transaction__pb2.DBCommitResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'transaction.TransactionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('transaction.TransactionService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TransactionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetCurrentTransactions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/transaction.TransactionService/GetCurrentTransactions',
            proto_dot_transaction__pb2.TransactionRequest.SerializeToString,
            proto_dot_transaction__pb2.CurrentTransactionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPastTransactions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/transaction.TransactionService/GetPastTransactions',
            proto_dot_transaction__pb2.PositionHistoryRequest.SerializeToString,
            proto_dot_transaction__pb2.PositionHistoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BidPlaced(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/transaction.TransactionService/BidPlaced',
            proto_dot_transaction__pb2.BidPlaceRequest.SerializeToString,
            proto_dot_transaction__pb2.DBCommitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BidFilled(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/transaction.TransactionService/BidFilled',
            proto_dot_transaction__pb2.BidFillRequest.SerializeToString,
            proto_dot_transaction__pb2.DBCommitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AskPlaced(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/transaction.TransactionService/AskPlaced',
            proto_dot_transaction__pb2.AskPlaceRequest.SerializeToString,
            proto_dot_transaction__pb2.DBCommitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AskFilled(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/transaction.TransactionService/AskFilled',
            proto_dot_transaction__pb2.AskFillRequest.SerializeToString,
            proto_dot_transaction__pb2.DBCommitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OrderFailedAfterBidPlaced(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/transaction.TransactionService/OrderFailedAfterBidPlaced',
            proto_dot_transaction__pb2.UuidRequest.SerializeToString,
            proto_dot_transaction__pb2.DBCommitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OrderFailedAfterAskPlaced(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/transaction.TransactionService/OrderFailedAfterAskPlaced',
            proto_dot_transaction__pb2.UuidRequest.SerializeToString,
            proto_dot_transaction__pb2.DBCommitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto/transaction.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'proto/transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17proto/transaction.proto\x12\x0btransaction\"\xdb\x03\n\x0bTransaction\x12\x10\n\x08\x62id_uuid\x18\x01 \x01(\t\x12\x16\n\x0e\x62id_created_at\x18\x02 \x01(\t\x12\x11\n\tbid_price\x18\x03 \x01(\x02\x12\x0f\n\x07\x62id_krw\x18\x04 \x01(\x02\x12\x0f\n\x07\x62id_fee\x18\x05 \x01(\x02\x12\x12\n\nbid_failed\x18\x06 \x01(\x05\x12\x12\n\nask_failed\x18\x07 \x01(\x05\x12\x14\n\x0corder_status\x18\x08 \x01(\x05\x12\x15\n\rtether_volume\x18\t \x01(\x02\x12\x1a\n\rbid_filled_at\x18\n \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x61sk_uuid\x18\x0b \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0e\x61sk_created_at\x18\x0c \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rask_filled_at\x18\r \x01(\tH\x03\x88\x01\x01\x12\x16\n\task_price\x18\x0e \x01(\x02H\x04\x88\x01\x01\x12\x14\n\x07\x61sk_fee\x18\x0f \x01(\tH\x05\x88\x01\x01\x12\x14\n\x07revenue\x18\x10 \x01(\tH\x06\x88\x01\x01\x42\x10\n\x0e_bid_filled_atB\x0b\n\t_ask_uuidB\x11\n\x0f_ask_created_atB\x10\n\x0e_ask_filled_atB\x0c\n\n_ask_priceB\n\n\x08_ask_feeB\n\n\x08_revenue\"7\n\x12TransactionRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62ot_name\x18\x02 \x01(\t\"I\n\x1a\x43urrentTransactionResponse\x12+\n\tpositions\x18\x01 \x03(\x0b\x32\x18.transaction.Transaction\"O\n\x16PositionHistoryRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x12\n\nstart_time\x18\x02 \x01(\t\x12\x10\n\x08\x65nd_time\x18\x03 \x01(\t\"D\n\x17PositionHistoryResponse\x12)\n\x07history\x18\x01 \x03(\x0b\x32\x18.transaction.Transaction\"8\n\x10\x44\x42\x43ommitResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"^\n\x0f\x42idPlaceRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\x12\x11\n\tbid_price\x18\x03 \x01(\x02\x12\x15\n\rtether_volume\x18\x04 \x01(\x02\"3\n\x0e\x42idFillRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\"Y\n\x0f\x41skPlaceRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x62id_uuid\x18\x02 \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x03 \x01(\t\x12\x11\n\task_price\x18\x04 \x01(\x02\"D\n\x0e\x41skFillRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x10\n\x08\x61sk_uuid\x18\x02 \x01(\t\x12\x0f\n\x07\x61sk_fee\x18\x03 \x01(\t\",\n\x0bUuidRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t2\xac\x05\n\x12TransactionService\x12\x62\n\x16GetCurrentTransactions\x12\x1f.transaction.TransactionRequest\x1a\'.transaction.CurrentTransactionResponse\x12`\n\x13GetPastTransactions\x12#.transaction.PositionHistoryRequest\x1a$.transaction.PositionHistoryResponse\x12H\n\tBidPlaced\x12\x1c.transaction.BidPlaceRequest\x1a\x1d.transaction.DBCommitResponse\x12G\n\tBidFilled\x12\x1b.transaction.BidFillRequest\x1a\x1d.transaction.DBCommitResponse\x12H\n\tAskPlaced\x12\x1c.transaction.AskPlaceRequest\x1a\x1d.transaction.DBCommitResponse\x12G\n\tAskFilled\x12\x1b.transaction.AskFillRequest\x1a\x1d.transaction.DBCommitResponse\x12T\n\x19OrderFailedAfterBidPlaced\x12\x18.transaction.UuidRequest\x1a\x1d.transaction.DBCommitResponse\x12T\n\x19OrderFailedAfterAskPlaced\x12\x18.transaction.UuidRequest\x1a\x1d.transaction.DBCommitResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto.transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRANSACTION']._serialized_start=41
  _globals['_TRANSACTION']._serialized_end=516
  _globals['_TRANSACTIONREQUEST']._serialized_start=518
  _globals['_TRANSACTIONREQUEST']._serialized_end=573
  _globals['_CURRENTTRANSACTIONRESPONSE']._serialized_start=575
  _globals['_CURRENTTRANSACTIONRESPONSE']._serialized_end=648
  _globals['_POSITIONHISTORYREQUEST']._serialized_start=650
  _globals['_POSITIONHISTORYREQUEST']._serialized_end=729
  _globals['_POSITIONHISTORYRESPONSE']._serialized_start=731
  _globals['_POSITIONHISTORYRESPONSE']._serialized_end=799
  _globals['_DBCOMMITRESPONSE']._serialized_start=801
  _globals['_DBCOMMITRESPONSE']._serialized_end=857
  _globals['_BIDPLACEREQUEST']._serialized_start=859
  _globals['_BIDPLACEREQUEST']._serialized_end=953
  _globals['_BIDFILLREQUEST']._serialized_start=955
  _globals['_BIDFILLREQUEST']._serialized_end=1006
  _globals['_ASKPLACEREQUEST']._serialized_start=1008
  _globals['_ASKPLACEREQUEST']._serialized_end=1097
  _globals['_ASKFILLREQUEST']._serialized_start=1099
  _globals['_ASKFILLREQUEST']._serialized_end=1167
  _globals['_UUIDREQUEST']._serialized_start=1169
  _globals['_UUIDREQUEST']._serialized_end=1213
  _globals['_TRANSACTIONSERVICE']._serialized_start=1216
  _globals['_TRANSACTIONSERVICE']._serialized_end=1900
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto/tetherbot.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'proto/tetherbot.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15proto/tetherbot.proto\x12\x03\x62ot\"\x9c\x01\n\x08Position\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x16\n\x0e\x62id_order_uuid\x18\x02 \x01(\t\x12\x13\n\x0b\x65ntry_price\x18\x03 \x01(\x01\x12\x0e\n\x06volume\x18\x04 \x01(\x01\x12\x16\n\x0e\x61sk_order_uuid\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x14\n\x0ctarget_price\x18\x07 \x01(\x02\"\x1d\n\nKeyRequest\x12\x0f\n\x07\x64\x62_auth\x18\x01 \x01(\t\"3\n\x0bKeyResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"6\n\x16\x42\x61tchPositionsResponse\x12\x1c\n\x05\x62\x61tch\x18\x01 \x03(\x0b\x32\r.bot.Position\"]\n\x11PositionsResponse\x12\x14\n\x0cposition_idx\x18\x01 \x01(\x05\x12\x1f\n\x08position\x18\x02 \x01(\x0b\x32\r.bot.Position\x12\x11\n\ttimestamp\x18\x03 \x01(\t\"<\n\x12MarketDataResponse\x12\r\n\x05price\x18\x01 \x01(\x01\x12\x17\n\x0ftimestamp_epoch\x18\x02 \x01(\x03\x32\xb5\x02\n\x10TetherBotService\x12\x43\n\x13GetCurrentPositions\x12\x0f.bot.KeyRequest\x1a\x1b.bot.BatchPositionsResponse\x12\x44\n\x17StreamRealTimePositions\x12\x0f.bot.KeyRequest\x1a\x16.bot.PositionsResponse0\x01\x12?\n\x11StreamMarketValue\x12\x0f.bot.KeyRequest\x1a\x17.bot.MarketDataResponse0\x01\x12*\n\x05Start\x12\x0f.bot.KeyRequest\x1a\x10.bot.KeyResponse\x12)\n\x04Stop\x12\x0f.bot.KeyRequest\x1a\x10.bot.KeyResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto.tetherbot_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_POSITION']._serialized_start=31
  _globals['_POSITION']._serialized_end=187
  _globals['_KEYREQUEST']._serialized_start=189
  _globals['_KEYREQUEST']._serialized_end=218
  _globals['_KEYRESPONSE']._serialized_start=220
  _globals['_KEYRESPONSE']._serialized_end=271
  _globals['_BATCHPOSITIONSRESPONSE']._serialized_start=273
  _globals['_BATCHPOSITIONSRESPONSE']._serialized_end=327
  _globals['_POSITIONSRESPONSE']._serialized_start=329
  _globals['_POSITIONSRESPONSE']._serialized_end=422
  _globals['_MARKETDATARESPONSE']._serialized_start=424
  _globals['_MARKETDATARESPONSE']._serialized_end=484
  _globals['_TETHERBOTSERVICE']._serialized_start=487
  _globals['_TETHERBOTSERVICE']._serialized_end=796
# @@protoc_insertion_point(module_scope)
